@@ -1,6 +1,6 @@
-;;; copilot.el --- An unofficial Copilot plugin -*- lexical-binding: t; -*-
+;;; copilot.el --- An Emacs plugin for GitHub Copilot -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2022-2025 copilot-emacs maintainers
+;; Copyright (C) 2022-2026 copilot-emacs maintainers
 
 ;; Author: zerol <z@zerol.me>
 ;; Maintainer: Emil van der Westhuizen
@@ -9,8 +9,8 @@
 ;;             Bozhidar Batsov <bozhidar@batsov.dev>
 ;; URL: https://github.com/copilot-emacs/copilot.el
 ;; Package-Requires: ((emacs "27.2") (editorconfig "0.8.2") (jsonrpc "1.0.14") (compat "30") (track-changes "1.4"))
-;; Package-Version: 20260225.538
-;; Package-Revision: 0e1c017162f5
+;; Package-Version: 20260226.819
+;; Package-Revision: 7904f13d52e8
 ;; Keywords: convenience copilot
 
 ;; The MIT License (MIT)
@@ -35,7 +35,7 @@
 
 ;;; Commentary:
 
-;; An unofficial Copilot plugin for Emacs
+;; An Emacs plugin for GitHub Copilot
 
 ;;; Code:
 
@@ -154,7 +154,8 @@ When non-nil, completions in Lisp modes are adjusted to ensure that
 parentheses remain balanced within the surrounding top-level form.
 Set to nil to use completions from the server verbatim."
   :type 'boolean
-  :group 'copilot)
+  :group 'copilot
+  :package-version '(copilot . "0.4"))
 
 (defcustom copilot-indentation-alist
   (append '((emacs-lisp-mode lisp-indent-offset)
@@ -242,7 +243,7 @@ from available models."
   :type '(choice (const :tag "Default" nil)
                  (string :tag "Model ID"))
   :group 'copilot
-  :package-version '(copilot . "0.5"))
+  :package-version '(copilot . "0.4"))
 
 (defvar-local copilot--overlay nil
   "Overlay for Copilot completion.")
